aboutsummaryrefslogtreecommitdiff
path: root/platform/linux-dpdk/include
diff options
context:
space:
mode:
authorMatias Elo <matias.elo@nokia.com>2021-01-13 09:36:21 +0200
committerMatias Elo <matias.elo@nokia.com>2021-01-15 08:18:37 +0200
commit723c2ecad81788b674da630bf69aac35d1216a28 (patch)
tree84a3a128f14ba69a2a65bf8521f3b0b86f14bc9d /platform/linux-dpdk/include
parentb3bf199401d31571fb70a25379f053dfb6c310a8 (diff)
Port e185f5343 "linux-gen: rename some global symbols in the static library"
Port original commit from linux-generic. Signed-off-by: Matias Elo <matias.elo@nokia.com> Reviewed-by: Jere Leppänen <jere.leppanen@nokia.com>
Diffstat (limited to 'platform/linux-dpdk/include')
-rw-r--r--platform/linux-dpdk/include/odp_eventdev_internal.h6
-rw-r--r--platform/linux-dpdk/include/odp_packet_internal.h14
-rw-r--r--platform/linux-dpdk/include/odp_packet_io_internal.h22
-rw-r--r--platform/linux-dpdk/include/odp_queue_basic_internal.h14
4 files changed, 28 insertions, 28 deletions
diff --git a/platform/linux-dpdk/include/odp_eventdev_internal.h b/platform/linux-dpdk/include/odp_eventdev_internal.h
index db0010883..29e9d7a58 100644
--- a/platform/linux-dpdk/include/odp_eventdev_internal.h
+++ b/platform/linux-dpdk/include/odp_eventdev_internal.h
@@ -151,8 +151,8 @@ typedef struct {
uint8_t started;
} eventdev_local_t;
-extern eventdev_global_t *eventdev_gbl;
-extern __thread eventdev_local_t eventdev_local;
+extern eventdev_global_t *_odp_eventdev_gbl;
+extern __thread eventdev_local_t _odp_eventdev_local;
int service_setup(uint32_t service_id);
@@ -180,7 +180,7 @@ static inline odp_queue_t queue_from_qentry(queue_entry_t *queue)
static inline queue_entry_t *qentry_from_index(uint32_t queue_id)
{
- return &eventdev_gbl->queue[queue_id];
+ return &_odp_eventdev_gbl->queue[queue_id];
}
static inline queue_entry_t *qentry_from_handle(odp_queue_t handle)
diff --git a/platform/linux-dpdk/include/odp_packet_io_internal.h b/platform/linux-dpdk/include/odp_packet_io_internal.h
index a8fc81f21..fbb41377a 100644
--- a/platform/linux-dpdk/include/odp_packet_io_internal.h
+++ b/platform/linux-dpdk/include/odp_packet_io_internal.h
@@ -186,7 +186,7 @@ typedef struct pktio_if_ops {
const odp_pktout_queue_param_t *p);
} pktio_if_ops_t;
-extern void *pktio_entry_ptr[];
+extern void *_odp_pktio_entry_ptr[];
static inline pktio_entry_t *get_pktio_entry(odp_pktio_t pktio)
{
@@ -203,7 +203,7 @@ static inline pktio_entry_t *get_pktio_entry(odp_pktio_t pktio)
idx = odp_pktio_index(pktio);
- return pktio_entry_ptr[idx];
+ return _odp_pktio_entry_ptr[idx];
}
static inline int pktio_cls_enabled(pktio_entry_t *entry)
@@ -232,19 +232,19 @@ static inline void _odp_pktio_tx_ts_set(pktio_entry_t *entry)
odp_atomic_store_u64(&entry->s.tx_ts, ts_val.u64);
}
-extern const pktio_if_ops_t null_pktio_ops;
-extern const pktio_if_ops_t dpdk_pktio_ops;
+extern const pktio_if_ops_t _odp_null_pktio_ops;
+extern const pktio_if_ops_t _odp_dpdk_pktio_ops;
extern const pktio_if_ops_t * const pktio_if_ops[];
/* Dummy function required by odp_pktin_recv_mq_tmo() */
static inline int
-sock_recv_mq_tmo_try_int_driven(const struct odp_pktin_queue_t queues[],
- unsigned num_q ODP_UNUSED,
- unsigned *from ODP_UNUSED,
- odp_packet_t packets[] ODP_UNUSED,
- int num ODP_UNUSED,
- uint64_t usecs ODP_UNUSED,
- int *trial_successful) {
+_odp_sock_recv_mq_tmo_try_int_driven(const struct odp_pktin_queue_t queues[],
+ unsigned int num_q ODP_UNUSED,
+ unsigned int *from ODP_UNUSED,
+ odp_packet_t packets[] ODP_UNUSED,
+ int num ODP_UNUSED,
+ uint64_t usecs ODP_UNUSED,
+ int *trial_successful) {
(void)queues;
*trial_successful = 0;
diff --git a/platform/linux-dpdk/include/odp_queue_basic_internal.h b/platform/linux-dpdk/include/odp_queue_basic_internal.h
index c9f4d5e8d..c3ddaf334 100644
--- a/platform/linux-dpdk/include/odp_queue_basic_internal.h
+++ b/platform/linux-dpdk/include/odp_queue_basic_internal.h
@@ -84,7 +84,7 @@ typedef struct queue_global_t {
} queue_global_t;
-extern queue_global_t *queue_glb;
+extern queue_global_t *_odp_queue_glb;
static inline uint32_t queue_to_index(odp_queue_t handle)
{
@@ -95,7 +95,7 @@ static inline uint32_t queue_to_index(odp_queue_t handle)
static inline queue_entry_t *qentry_from_index(uint32_t queue_id)
{
- return &queue_glb->queue[queue_id];
+ return &_odp_queue_glb->queue[queue_id];
}
static inline odp_queue_t queue_from_index(uint32_t queue_id)
@@ -108,13 +108,13 @@ static inline queue_entry_t *qentry_from_handle(odp_queue_t handle)
return (queue_entry_t *)(uintptr_t)handle;
}
-void queue_spsc_init(queue_entry_t *queue, uint32_t queue_size);
+void _odp_queue_spsc_init(queue_entry_t *queue, uint32_t queue_size);
/* Functions for schedulers */
-void sched_queue_set_status(uint32_t queue_index, int status);
-int sched_queue_deq(uint32_t queue_index, odp_event_t ev[], int num,
- int update_status);
-int sched_queue_empty(uint32_t queue_index);
+void _odp_sched_queue_set_status(uint32_t queue_index, int status);
+int _odp_sched_queue_deq(uint32_t queue_index, odp_event_t ev[], int num,
+ int update_status);
+int _odp_sched_queue_empty(uint32_t queue_index);
#ifdef __cplusplus
}
diff --git a/platform/linux-dpdk/include/odp_packet_internal.h b/platform/linux-dpdk/include/odp_packet_internal.h
index 20a46a577..927e609d4 100644
--- a/platform/linux-dpdk/include/odp_packet_internal.h
+++ b/platform/linux-dpdk/include/odp_packet_internal.h
@@ -43,7 +43,7 @@ extern "C" {
#undef vector
#endif
/** Minimum segment length expected by packet_parse_common() */
#define PACKET_PARSE_SEG_LEN 96
ODP_STATIC_ASSERT(sizeof(_odp_packet_input_flags_t) == sizeof(uint64_t),
@@ -228,9 +228,9 @@ static inline void packet_set_len(odp_packet_hdr_t *pkt_hdr, uint32_t len)
int _odp_packet_copy_md_to_packet(odp_packet_t srcpkt, odp_packet_t dstpkt);
/* Perform packet parse up to a given protocol layer */
-int packet_parse_layer(odp_packet_hdr_t *pkt_hdr,
- odp_proto_layer_t layer,
- odp_proto_chksums_t chksums);
+int _odp_packet_parse_layer(odp_packet_hdr_t *pkt_hdr,
+ odp_proto_layer_t layer,
+ odp_proto_chksums_t chksums);
/* Reset parser metadata for a new parse */
static inline void packet_parse_reset(odp_packet_hdr_t *pkt_hdr, int all)
@@ -276,9 +276,9 @@ static inline void packet_set_ts(odp_packet_hdr_t *pkt_hdr, odp_time_t *ts)
}
}
-int packet_parse_common(packet_parser_t *pkt_hdr, const uint8_t *ptr,
- uint32_t pkt_len, uint32_t seg_len, int layer,
- odp_proto_chksums_t chksums);
+int _odp_packet_parse_common(packet_parser_t *pkt_hdr, const uint8_t *ptr,
+ uint32_t pkt_len, uint32_t seg_len, int layer,
+ odp_proto_chksums_t chksums);
int _odp_packet_set_data(odp_packet_t pkt, uint32_t offset,
uint8_t c, uint32_t len);
@@ -43,7 +43,7 @@ extern "C" {
#undef vector
#endif
-/** Minimum segment length expected by packet_parse_common() */
+/** Minimum segment length expected by _odp_packet_parse_common() */
#define PACKET_PARSE_SEG_LEN 96
ODP_STATIC_ASSERT(sizeof(_odp_packet_input_flags_t) == sizeof(uint64_t),